@@ -1,17 +1,11 @@
 import ast
+import tokenize
 from typing import Generator, List, Optional
 
 from .act_node import ActNode
 from .block import Block
 from .exceptions import AAAError, EmptyBlock, ValidationError
-from .helpers import (
-    find_stringy_lines,
-    format_errors,
-    function_is_noop,
-    get_first_token,
-    get_last_token,
-    line_is_comment,
-)
+from .helpers import format_errors, function_is_noop, get_first_token, get_last_token, line_is_comment
 from .line_markers import LineMarkers
 from .types import ActNodeType, LineType
 
@@ -35,6 +29,7 @@ class Function:
             method.
         line_markers: Line-wise marking for this function.
         node: AST for the test function / method.
+        tokens: Slice of the file's tokens that make up this test function.
 
     Note:
         "line number" means the number of the line in the file (the usual
@@ -42,11 +37,12 @@ class Function:
         to the test definition.
     """
 
-    def __init__(self, node: ast.FunctionDef, file_lines: List[str]):
+    def __init__(self, node: ast.FunctionDef, file_lines: List[str], file_tokens: List[tokenize.TokenInfo]):
         """
         Args:
             node
             file_lines: Lines of file under test.
+            file_tokens: Tokens for file passed by Flake8.
         """
         self.node = node
         self.first_line_no: int = get_first_token(self.node).start[0]
@@ -57,6 +53,7 @@ class Function:
         self.act_block: Optional[Block] = None
         self.assert_block: Optional[Block] = None
         self.line_markers = LineMarkers(self.lines, self.first_line_no)
+        self.tokens = file_tokens
 
     def __str__(self, errors: Optional[List[AAAError]] = None) -> str:
         out = '------+------------------------------------------------------------------------\n'
@@ -221,11 +218,6 @@ class Function:
         Note:
             Does not spot the closing ``):`` of a function when it occurs on
             its own line.
-
-        Note:
-            Can not use ``helpers.build_footprint()`` because function nodes
-            cover the whole function. In this case, just the def lines are
-            wanted with any decorators.
         """
         first_index = get_first_token(self.node).start[0] - self.first_line_no  # Should usually be 0
         try:
@@ -243,13 +235,16 @@ class Function:
         covering them as blank line BL.
 
         Returns:
-            Number of blank lines found with no stringy parent node.
+            Number of blank lines found.
         """
         counter = 0
-        stringy_lines = find_stringy_lines(self.node, self.first_line_no)
-        for offset, line in enumerate(self.lines):
-            if offset not in stringy_lines and line.strip() == '':
-                counter += 1
-                self.line_markers.types[offset] = LineType.blank_line
+        previous = None
+        for t in self.tokens:
+            if t.type == tokenize.NL:
+                assert previous is not None, "Unexpected NL token before any other tokens seen"
+                if previous.type == tokenize.NL or previous.type == tokenize.NEWLINE:
+                    self.line_markers.types[t.start[0] - self.first_line_no] = LineType.blank_line
+                    counter += 1
+            previous = t
 
         return counter
